@@ -17,6 +17,7 @@ def _get_kwargs(
     scheduled_for: Union[Unset, None, datetime.datetime] = UNSET,
     scheduled_in_secs: Union[Unset, None, int] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
+    include_header: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/w/{workspace}/jobs/run_wait_result/p/{path}".format(client.base_url, workspace=workspace, path=path)
 
@@ -34,6 +35,8 @@ def _get_kwargs(
 
     params["parent_job"] = parent_job
 
+    params["include_header"] = include_header
+
     params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
     json_json_body = json_body.to_dict()
@@ -67,6 +70,7 @@ def sync_detailed(
     scheduled_for: Union[Unset, None, datetime.datetime] = UNSET,
     scheduled_in_secs: Union[Unset, None, int] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
+    include_header: Union[Unset, None, str] = UNSET,
 ) -> Response[Any]:
     """run script by path
 
@@ -76,6 +80,7 @@ def sync_detailed(
         scheduled_for (Union[Unset, None, datetime.datetime]):
         scheduled_in_secs (Union[Unset, None, int]):
         parent_job (Union[Unset, None, str]):
+        include_header (Union[Unset, None, str]):
         json_body (RunWaitResultScriptByPathJsonBody):
 
     Returns:
@@ -90,6 +95,7 @@ def sync_detailed(
         scheduled_for=scheduled_for,
         scheduled_in_secs=scheduled_in_secs,
         parent_job=parent_job,
+        include_header=include_header,
     )
 
     response = httpx.request(
@@ -109,6 +115,7 @@ async def asyncio_detailed(
     scheduled_for: Union[Unset, None, datetime.datetime] = UNSET,
     scheduled_in_secs: Union[Unset, None, int] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
+    include_header: Union[Unset, None, str] = UNSET,
 ) -> Response[Any]:
     """run script by path
 
@@ -118,6 +125,7 @@ async def asyncio_detailed(
         scheduled_for (Union[Unset, None, datetime.datetime]):
         scheduled_in_secs (Union[Unset, None, int]):
         parent_job (Union[Unset, None, str]):
+        include_header (Union[Unset, None, str]):
         json_body (RunWaitResultScriptByPathJsonBody):
 
     Returns:
@@ -132,6 +140,7 @@ async def asyncio_detailed(
         scheduled_for=scheduled_for,
         scheduled_in_secs=scheduled_in_secs,
         parent_job=parent_job,
+        include_header=include_header,
     )
 
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
