@@ -30,6 +30,8 @@ class DeleteCompletedJobResponse200:
             the execution of this script will be permissioned_as and by extension its DT_TOKEN.
         is_flow_step (bool):
         is_skipped (bool):
+        email (str):
+        visible_to_owner (bool):
         workspace_id (Union[Unset, str]):
         parent_job (Union[Unset, str]):
         script_path (Union[Unset, str]):
@@ -58,6 +60,8 @@ class DeleteCompletedJobResponse200:
     permissioned_as: str
     is_flow_step: bool
     is_skipped: bool
+    email: str
+    visible_to_owner: bool
     workspace_id: Union[Unset, str] = UNSET
     parent_job: Union[Unset, str] = UNSET
     script_path: Union[Unset, str] = UNSET
@@ -90,6 +94,8 @@ class DeleteCompletedJobResponse200:
         permissioned_as = self.permissioned_as
         is_flow_step = self.is_flow_step
         is_skipped = self.is_skipped
+        email = self.email
+        visible_to_owner = self.visible_to_owner
         workspace_id = self.workspace_id
         parent_job = self.parent_job
         script_path = self.script_path
@@ -132,6 +138,8 @@ class DeleteCompletedJobResponse200:
                 "permissioned_as": permissioned_as,
                 "is_flow_step": is_flow_step,
                 "is_skipped": is_skipped,
+                "email": email,
+                "visible_to_owner": visible_to_owner,
             }
         )
         if workspace_id is not UNSET:
@@ -192,6 +200,10 @@ class DeleteCompletedJobResponse200:
 
         is_skipped = d.pop("is_skipped")
 
+        email = d.pop("email")
+
+        visible_to_owner = d.pop("visible_to_owner")
+
         workspace_id = d.pop("workspace_id", UNSET)
 
         parent_job = d.pop("parent_job", UNSET)
@@ -254,6 +266,8 @@ class DeleteCompletedJobResponse200:
             permissioned_as=permissioned_as,
             is_flow_step=is_flow_step,
             is_skipped=is_skipped,
+            email=email,
+            visible_to_owner=visible_to_owner,
             workspace_id=workspace_id,
             parent_job=parent_job,
             script_path=script_path,
