@@ -3,7 +3,7 @@ from enum import Enum
 
 class FlowStatusFailureModuleType(str, Enum):
     WAITINGFORPRIORSTEPS = "WaitingForPriorSteps"
-    WAITINGFOREVENT = "WaitingForEvent"
+    WAITINGFOREVENTS = "WaitingForEvents"
     WAITINGFOREXECUTOR = "WaitingForExecutor"
     INPROGRESS = "InProgress"
     SUCCESS = "Success"
