@@ -20,6 +20,7 @@ class GetScriptByPathResponse200:
         hash_ (str):
         path (str):
         summary (str):
+        description (str):
         content (str):
         created_by (str):
         created_at (datetime.datetime):
@@ -33,7 +34,6 @@ class GetScriptByPathResponse200:
         workspace_id (Union[Unset, str]):
         parent_hashes (Union[Unset, List[str]]): The first element is the direct parent of the script, the second is the
             parent of the first, etc
-        description (Union[Unset, str]):
         schema (Union[Unset, GetScriptByPathResponse200Schema]):
         lock (Union[Unset, str]):
         lock_error_logs (Union[Unset, str]):
@@ -42,6 +42,7 @@ class GetScriptByPathResponse200:
     hash_: str
     path: str
     summary: str
+    description: str
     content: str
     created_by: str
     created_at: datetime.datetime
@@ -54,7 +55,6 @@ class GetScriptByPathResponse200:
     starred: bool
     workspace_id: Union[Unset, str] = UNSET
     parent_hashes: Union[Unset, List[str]] = UNSET
-    description: Union[Unset, str] = UNSET
     schema: Union[Unset, GetScriptByPathResponse200Schema] = UNSET
     lock: Union[Unset, str] = UNSET
     lock_error_logs: Union[Unset, str] = UNSET
@@ -64,6 +64,7 @@ class GetScriptByPathResponse200:
         hash_ = self.hash_
         path = self.path
         summary = self.summary
+        description = self.description
         content = self.content
         created_by = self.created_by
         created_at = self.created_at.isoformat()
@@ -83,7 +84,6 @@ class GetScriptByPathResponse200:
         if not isinstance(self.parent_hashes, Unset):
             parent_hashes = self.parent_hashes
 
-        description = self.description
         schema: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.schema, Unset):
             schema = self.schema.to_dict()
@@ -98,6 +98,7 @@ class GetScriptByPathResponse200:
                 "hash": hash_,
                 "path": path,
                 "summary": summary,
+                "description": description,
                 "content": content,
                 "created_by": created_by,
                 "created_at": created_at,
@@ -114,8 +115,6 @@ class GetScriptByPathResponse200:
             field_dict["workspace_id"] = workspace_id
         if parent_hashes is not UNSET:
             field_dict["parent_hashes"] = parent_hashes
-        if description is not UNSET:
-            field_dict["description"] = description
         if schema is not UNSET:
             field_dict["schema"] = schema
         if lock is not UNSET:
@@ -134,6 +133,8 @@ class GetScriptByPathResponse200:
 
         summary = d.pop("summary")
 
+        description = d.pop("description")
+
         content = d.pop("content")
 
         created_by = d.pop("created_by")
@@ -158,8 +159,6 @@ class GetScriptByPathResponse200:
 
         parent_hashes = cast(List[str], d.pop("parent_hashes", UNSET))
 
-        description = d.pop("description", UNSET)
-
         _schema = d.pop("schema", UNSET)
         schema: Union[Unset, GetScriptByPathResponse200Schema]
         if isinstance(_schema, Unset):
@@ -175,6 +174,7 @@ class GetScriptByPathResponse200:
             hash_=hash_,
             path=path,
             summary=summary,
+            description=description,
             content=content,
             created_by=created_by,
             created_at=created_at,
@@ -187,7 +187,6 @@ class GetScriptByPathResponse200:
             starred=starred,
             workspace_id=workspace_id,
             parent_hashes=parent_hashes,
-            description=description,
             schema=schema,
             lock=lock,
             lock_error_logs=lock_error_logs,
