@@ -1,8 +1,9 @@
-from typing import Any, Dict, List, Type, TypeVar
+from typing import Any, Dict, List, Type, TypeVar, Union
 
 import attr
 
 from ..models.identity_type import IdentityType
+from ..types import UNSET, Unset
 
 T = TypeVar("T", bound="Identity")
 
@@ -12,14 +13,18 @@ class Identity:
     """
     Attributes:
         type (IdentityType):
+        flow (Union[Unset, bool]):
     """
 
     type: IdentityType
+    flow: Union[Unset, bool] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         type = self.type.value
 
+        flow = self.flow
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -27,6 +32,8 @@ class Identity:
                 "type": type,
             }
         )
+        if flow is not UNSET:
+            field_dict["flow"] = flow
 
         return field_dict
 
@@ -35,8 +42,11 @@ class Identity:
         d = src_dict.copy()
         type = IdentityType(d.pop("type"))
 
+        flow = d.pop("flow", UNSET)
+
         identity = cls(
             type=type,
+            flow=flow,
         )
 
         identity.additional_properties = d
