@@ -25,6 +25,8 @@ class QueuedJob:
         permissioned_as (str): The user (u/userfoo) or group (g/groupfoo) whom
             the execution of this script will be permissioned_as and by extension its DT_TOKEN.
         is_flow_step (bool):
+        email (str):
+        visible_to_owner (bool):
         workspace_id (Union[Unset, str]):
         parent_job (Union[Unset, str]):
         created_by (Union[Unset, str]):
@@ -51,6 +53,8 @@ class QueuedJob:
     job_kind: QueuedJobJobKind
     permissioned_as: str
     is_flow_step: bool
+    email: str
+    visible_to_owner: bool
     workspace_id: Union[Unset, str] = UNSET
     parent_job: Union[Unset, str] = UNSET
     created_by: Union[Unset, str] = UNSET
@@ -79,6 +83,8 @@ class QueuedJob:
 
         permissioned_as = self.permissioned_as
         is_flow_step = self.is_flow_step
+        email = self.email
+        visible_to_owner = self.visible_to_owner
         workspace_id = self.workspace_id
         parent_job = self.parent_job
         created_by = self.created_by
@@ -131,6 +137,8 @@ class QueuedJob:
                 "job_kind": job_kind,
                 "permissioned_as": permissioned_as,
                 "is_flow_step": is_flow_step,
+                "email": email,
+                "visible_to_owner": visible_to_owner,
             }
         )
         if workspace_id is not UNSET:
@@ -187,6 +195,10 @@ class QueuedJob:
 
         is_flow_step = d.pop("is_flow_step")
 
+        email = d.pop("email")
+
+        visible_to_owner = d.pop("visible_to_owner")
+
         workspace_id = d.pop("workspace_id", UNSET)
 
         parent_job = d.pop("parent_job", UNSET)
@@ -270,6 +282,8 @@ class QueuedJob:
             job_kind=job_kind,
             permissioned_as=permissioned_as,
             is_flow_step=is_flow_step,
+            email=email,
+            visible_to_owner=visible_to_owner,
             workspace_id=workspace_id,
             parent_job=parent_job,
             created_by=created_by,
