@@ -25,6 +25,7 @@ class QueuedJobFlowStatusFailureModule:
         branch_chosen (Union[Unset, QueuedJobFlowStatusFailureModuleBranchChosen]):
         branchall (Union[Unset, QueuedJobFlowStatusFailureModuleBranchall]):
         approvers (Union[Unset, List[QueuedJobFlowStatusFailureModuleApproversItem]]):
+        parent_module (Union[Unset, str]):
     """
 
     type: QueuedJobFlowStatusFailureModuleType
@@ -36,6 +37,7 @@ class QueuedJobFlowStatusFailureModule:
     branch_chosen: Union[Unset, QueuedJobFlowStatusFailureModuleBranchChosen] = UNSET
     branchall: Union[Unset, QueuedJobFlowStatusFailureModuleBranchall] = UNSET
     approvers: Union[Unset, List[QueuedJobFlowStatusFailureModuleApproversItem]] = UNSET
+    parent_module: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -68,6 +70,8 @@ class QueuedJobFlowStatusFailureModule:
 
                 approvers.append(approvers_item)
 
+        parent_module = self.parent_module
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -91,6 +95,8 @@ class QueuedJobFlowStatusFailureModule:
             field_dict["branchall"] = branchall
         if approvers is not UNSET:
             field_dict["approvers"] = approvers
+        if parent_module is not UNSET:
+            field_dict["parent_module"] = parent_module
 
         return field_dict
 
@@ -135,6 +141,8 @@ class QueuedJobFlowStatusFailureModule:
 
             approvers.append(approvers_item)
 
+        parent_module = d.pop("parent_module", UNSET)
+
         queued_job_flow_status_failure_module = cls(
             type=type,
             id=id,
@@ -145,6 +153,7 @@ class QueuedJobFlowStatusFailureModule:
             branch_chosen=branch_chosen,
             branchall=branchall,
             approvers=approvers,
+            parent_module=parent_module,
         )
 
         queued_job_flow_status_failure_module.additional_properties = d
