@@ -21,6 +21,7 @@ class User:
         created_at (datetime.datetime):
         operator (bool):
         disabled (bool):
+        folders (List[str]):
         groups (Union[Unset, List[str]]):
         usage (Union[Unset, UserUsage]):
     """
@@ -32,6 +33,7 @@ class User:
     created_at: datetime.datetime
     operator: bool
     disabled: bool
+    folders: List[str]
     groups: Union[Unset, List[str]] = UNSET
     usage: Union[Unset, UserUsage] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
@@ -45,6 +47,8 @@ class User:
 
         operator = self.operator
         disabled = self.disabled
+        folders = self.folders
+
         groups: Union[Unset, List[str]] = UNSET
         if not isinstance(self.groups, Unset):
             groups = self.groups
@@ -64,6 +68,7 @@ class User:
                 "created_at": created_at,
                 "operator": operator,
                 "disabled": disabled,
+                "folders": folders,
             }
         )
         if groups is not UNSET:
@@ -90,6 +95,8 @@ class User:
 
         disabled = d.pop("disabled")
 
+        folders = cast(List[str], d.pop("folders"))
+
         groups = cast(List[str], d.pop("groups", UNSET))
 
         _usage = d.pop("usage", UNSET)
@@ -107,6 +114,7 @@ class User:
             created_at=created_at,
             operator=operator,
             disabled=disabled,
+            folders=folders,
             groups=groups,
             usage=usage,
         )
